==> haskell-iproute-1.7.5-25-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-iproute.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: iproute
version: 1.7.5
id: iproute-1.7.5-LaHtwM3tSHK92d36jHL4m7
key: iproute-1.7.5-LaHtwM3tSHK92d36jHL4m7
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
homepage: http://www.mew.org/~kazu/proj/iproute/
synopsis: IP Routing Table
description:
    IP Routing Table is a tree of IP ranges
    to search one of them on the longest
    match base. It is a kind of TRIE with one
    way branching removed. Both IPv4 and IPv6
    are supported.
category: Algorithms, Network
abi: abfdff21cb75496e7442c739447b2837
exposed: True
exposed-modules:
    Data.IP Data.IP.Internal Data.IP.RouteTable
hidden-modules: Data.IP.Addr Data.IP.Mask Data.IP.Op Data.IP.Range
                Data.IP.RouteTable.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/iproute-1.7.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/iproute-1.7.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/iproute-1.7.5
hs-libraries: HSiproute-1.7.5-LaHtwM3tSHK92d36jHL4m7
depends:
    base-4.11.1.0 appar-0.1.4-J5mdtVuytVIKFPXD2MXW4E
    byteorder-1.0.4-JGHrMy8StI888DOmmSVbRy containers-0.5.11.0
    network-2.7.0.2-8yE8vwBlEy1KZPVD4sTAn
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             appar-0.1.4-J5mdtVuytVIKFPXD2MXW4E=1b595bcd8022342724185d5d05b7d4da
             byteorder-1.0.4-JGHrMy8StI888DOmmSVbRy=984ccd4a0add3e9c7ab736aab67c5afe
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             network-2.7.0.2-8yE8vwBlEy1KZPVD4sTAn=90fa8650caae170586ac66be24e6a39f
haddock-interfaces: /usr/share/doc/haskell-iproute/html/iproute.haddock
haddock-html: /usr/share/doc/haskell-iproute/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-iproute-1.7.5-26-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-iproute.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: iproute
version: 1.7.5
id: iproute-1.7.5-5WKQvAvCdW1I9tyIk3L7Hh
key: iproute-1.7.5-5WKQvAvCdW1I9tyIk3L7Hh
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
homepage: http://www.mew.org/~kazu/proj/iproute/
synopsis: IP Routing Table
description:
    IP Routing Table is a tree of IP ranges
    to search one of them on the longest
    match base. It is a kind of TRIE with one
    way branching removed. Both IPv4 and IPv6
    are supported.
category: Algorithms, Network
abi: 576aedcfb09fbcddb51a21476715b9a0
exposed: True
exposed-modules:
    Data.IP Data.IP.Internal Data.IP.RouteTable
hidden-modules: Data.IP.Addr Data.IP.Mask Data.IP.Op Data.IP.Range
                Data.IP.RouteTable.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/iproute-1.7.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/iproute-1.7.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/iproute-1.7.5
hs-libraries: HSiproute-1.7.5-5WKQvAvCdW1I9tyIk3L7Hh
depends:
    base-4.11.1.0 appar-0.1.4-J5mdtVuytVIKFPXD2MXW4E
    byteorder-1.0.4-JGHrMy8StI888DOmmSVbRy containers-0.5.11.0
    network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             appar-0.1.4-J5mdtVuytVIKFPXD2MXW4E=1b595bcd8022342724185d5d05b7d4da
             byteorder-1.0.4-JGHrMy8StI888DOmmSVbRy=984ccd4a0add3e9c7ab736aab67c5afe
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu=43a70846fe67ebce9998ba267f800e6d
haddock-interfaces: /usr/share/doc/haskell-iproute/html/iproute.haddock
haddock-html: /usr/share/doc/haskell-iproute/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
